@@ -151,6 +151,7 @@ sub run {
 	my $child = fork();
 	$self->Fatal("Couldn't fork: $!") unless defined $child;
 	if ($child) {
+	    $self->Info("Forked child PID $child");
 	    $c->close();
 	} else {
 	    $self->process_connection($c);
@@ -265,8 +266,6 @@ sub render_tracks {
 	    
     # generate the panels
     $self->Debug("Calling RenderPanels->new()");
-    my $tmpdir = $datasource->global_setting('tmp_slave') || $self->tmpdir;
-    $datasource->globals->setting('general',tmpimages=>$tmpdir);
     my $renderer = Bio::Graphics::Browser::RenderPanels->new(-segment  => $segment,
 							     -source   => $datasource,
 							     -settings => $settings,
@@ -361,12 +360,6 @@ sub clone_feature {
     return $clone;
 }
 
-sub tmpdir {
-    my $self   = shift;
-    my $tmpdir = File::Spec->tmpdir();
-    return File::Spec->catfile($tmpdir,'gbrowse_slave');
-}
-
 sub setup_environment {
     my $self    = shift;
     my $env_str = shift or return;
